==> eam-wshub-proxyclient-11.4-5-sources.jar: net/datastream/schemas/mp_fields/PURCHASEORDERTRACKINGID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Classe Java pour PURCHASEORDERTRACKINGID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="PURCHASEORDERTRACKINGID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TRACKCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PURCHASEORDERID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "PURCHASEORDERTRACKINGID_Type", propOrder = {
    "trackcode",
    "purchaseorderid"
})
public class PURCHASEORDERTRACKINGID_Type {

    @XmlElement(name = "TRACKCODE", required = true)
    protected QUANTITY trackcode;
    @XmlElement(name = "PURCHASEORDERID", required = true)
    protected PURCHASEORDERID_Type purchaseorderid;

    /**
     * Obtient la valeur de la propriété trackcode.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getTRACKCODE() {
        return trackcode;
    }

    /**
     * Définit la valeur de la propriété trackcode.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setTRACKCODE(QUANTITY value) {
        this.trackcode = value;
    }

    /**
     * Obtient la valeur de la propriété purchaseorderid.
     * 
     * @return
     *     possible object is
     *     {@link PURCHASEORDERID_Type }
     *     
     */
    public PURCHASEORDERID_Type getPURCHASEORDERID() {
        return purchaseorderid;
    }

    /**
     * Définit la valeur de la propriété purchaseorderid.
     * 
     * @param value
     *     allowed object is
     *     {@link PURCHASEORDERID_Type }
     *     
     */
    public void setPURCHASEORDERID(PURCHASEORDERID_Type value) {
        this.purchaseorderid = value;
    }

}

==> eam-wshub-proxyclient-12.0-sources.jar: net/datastream/schemas/mp_fields/PURCHASEORDERTRACKINGID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for PURCHASEORDERTRACKINGID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="PURCHASEORDERTRACKINGID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TRACKCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PURCHASEORDERID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "PURCHASEORDERTRACKINGID_Type", propOrder = {
    "trackcode",
    "purchaseorderid"
})
public class PURCHASEORDERTRACKINGID_Type {

    @XmlElement(name = "TRACKCODE", required = true)
    protected QUANTITY trackcode;
    @XmlElement(name = "PURCHASEORDERID", required = true)
    protected PURCHASEORDERID_Type purchaseorderid;

    /**
     * Gets the value of the trackcode property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getTRACKCODE() {
        return trackcode;
    }

    /**
     * Sets the value of the trackcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setTRACKCODE(QUANTITY value) {
        this.trackcode = value;
    }

    /**
     * Gets the value of the purchaseorderid property.
     * 
     * @return
     *     possible object is
     *     {@link PURCHASEORDERID_Type }
     *     
     */
    public PURCHASEORDERID_Type getPURCHASEORDERID() {
        return purchaseorderid;
    }

    /**
     * Sets the value of the purchaseorderid property.
     * 
     * @param value
     *     allowed object is
     *     {@link PURCHASEORDERID_Type }
     *     
     */
    public void setPURCHASEORDERID(PURCHASEORDERID_Type value) {
        this.purchaseorderid = value;
    }

}
